@@ -11,7 +11,7 @@
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '4.12'; # also change in Devel::NYTProf::Core
+our $VERSION = '4.24'; # also change in Devel::NYTProf::Core
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -50,7 +50,7 @@ __END__
 
 =head1 NAME
 
-Devel::NYTProf - Powerful fast feature-rich perl source code profiler
+Devel::NYTProf - Powerful fast feature-rich Perl source code profiler
 
 =head1 SYNOPSIS
 
@@ -460,26 +460,11 @@ likely to change in future.
 
 =head2 usecputime=1
 
-This option is deprecated and will be removed in a future version.
-See the L</clock=N> option.
+This option has been removed. Profiling won't be enabled if set.
 
-Measure user CPU + system CPU time instead of the real elapsed 'wall clock'
-time (which is the default). But there are better ways to do this, read on.
-
-Measuring CPU time has the advantage of making the measurements independent of
-time spent blocked waiting for the cpu or network i/o etc. But the method used
-by Cusecputime=1> also has the severe disadvantage of having typically I<far>
-less accurate timings.
-
-Most systems have a 0.01 second granularity in the results from the C<times()>
-system call.  With modern processors having multi- gigahertz clocks, 0.01
-seconds is like a lifetime. The 'ticks' of this CPU time clock
-happen so rarely relative to the activity of a most applications that you'd
-have to run the code for many hours to have any hope of reasonably useful results.
-
-A much better alternative is to use the L</clock=N> option to select a
-high-resolution CPU time clock, if available on your system, because that'll
-give you higher resolution and work for the subroutine profiler as well.
+Use the L</clock=N> option to select a high-resolution CPU time clock, if
+available on your system, instead. That will give you higher resolution and work
+for the subroutine profiler as well.
 
 =head2 file=...
 
@@ -511,9 +496,10 @@ When perl exits normally it runs any code defined in C<END> blocks.
 NYTProf defines an END block that finishes profiling and writes out the final
 profile data.
 
-If the process ends due to a signal then END blocks are not executed.
-The C<sigexit> option tells NYTProf to catch some signals (e.g. INT, HUP, PIPE,
-SEGV, BUS) and ensure a usable by executing:
+If the process ends due to a signal then END blocks are not executed so the
+profile will be incomplete and unusable.  The C<sigexit> option tells NYTProf
+to catch some signals (e.g. INT, HUP, PIPE, SEGV, BUS) and ensure a usable
+profile by executing:
 
     DB::finish_profile();
     exit 1;
@@ -1076,10 +1062,6 @@ I<cpu-time> clock instead of a real-time one. That should be much less
 noisy, though you will lose visibility of wait-times due to network
 and disk I/O, for example.
 
-If your system doesn't support the C<clock=N> option then you could try
-using the C<usecputime=1> option. That will give you cpu-time measurements
-but only at a very low 1/100th of a second resolution.
-
 =head1 BUGS
 
 Possibly. All complex software has bugs. Let me know if you find one.
